==> cherokee-0.4.11.tar.gz: cherokee-0.4.11/src/handler_mono.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */

/* Cherokee
 *
 * Authors:
 *      Alvaro Lopez Ortega <alvaro@alobbs.com>
 *
 * Copyright (C) 2001, 2002, 2003, 2004 Alvaro Lopez Ortega
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */

#ifndef __CHEROKEE_HANDLER_MONO_H__
#define __CHEROKEE_HANDLER_MONO_H__

#include "common.h"
#include "buffer.h"
#include "handler.h"
#include "connection.h"
#include "mime.h"


typedef struct {
	cherokee_handler_t handler;
	int                socket;
} cherokee_handler_mono_t;

#define MONO_HANDLER(x)  ((cherokee_handler_mono_t *)(x))


/* Library init function
 */
void mono_init ();

ret_t cherokee_handler_mono_new   (cherokee_handler_t **hdl, cherokee_connection_t *cnt, cherokee_table_t *properties);

/* virtual methods implementation
 */
ret_t cherokee_handler_mono_init        (cherokee_handler_mono_t *hdl);
ret_t cherokee_handler_mono_free        (cherokee_handler_mono_t *hdl);
ret_t cherokee_handler_mono_step        (cherokee_handler_mono_t *hdl, cherokee_buffer_t *buffer);
ret_t cherokee_handler_mono_add_headers (cherokee_handler_mono_t *hdl, cherokee_buffer_t *buffer);

#endif /* __CHEROKEE_HANDLER_MONO_H__ */

==> cherokee_0.4.13.orig.tar.gz: cherokee-0.4.13/src/handler_mono.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */

/* Cherokee
 *
 * Authors:
 *      Alvaro Lopez Ortega <alvaro@alobbs.com>
 *
 * Copyright (C) 2001, 2002, 2003, 2004 Alvaro Lopez Ortega
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */

#ifndef __CHEROKEE_HANDLER_MONO_H__
#define __CHEROKEE_HANDLER_MONO_H__

#include "common.h"

#include <sys/types.h>	
#include <sys/socket.h>
#include <sys/un.h>

#include "buffer.h"
#include "handler.h"
#include "connection.h"


typedef struct {
	cherokee_handler_t  handler;
	void               *connection;
	
	int                 socket;
	char               *socket_path;
	struct sockaddr_un  address;
} cherokee_handler_mono_t;

#define MONO_HANDLER(x)  ((cherokee_handler_mono_t *)(x))


/* Library init function
 */
void mono_init ();

ret_t cherokee_handler_mono_new   (cherokee_handler_t **hdl, cherokee_connection_t *cnt, cherokee_table_t *properties);

/* virtual methods implementation
 */
ret_t cherokee_handler_mono_init        (cherokee_handler_mono_t *hdl);
ret_t cherokee_handler_mono_free        (cherokee_handler_mono_t *hdl);
ret_t cherokee_handler_mono_step        (cherokee_handler_mono_t *hdl, cherokee_buffer_t *buffer);
ret_t cherokee_handler_mono_add_headers (cherokee_handler_mono_t *hdl, cherokee_buffer_t *buffer);

#endif /* __CHEROKEE_HANDLER_MONO_H__ */
